<?php

namespace Realestate\Video\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Realestate\Video\Http\Resources\VideoResource;
use Realestate\Video\Http\Resources\VideosCollection;
use Realestate\Video\Scopes\VideoPublicScope;
use Realestate\Video\Models\Video;

class VideoPublicController extends BaseController
{

    /**
     * Show video's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Video::pushScope(new RequestScope())
            ->pushScope(new VideoPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $videos = new VideosCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('video::video.names'))
            ->view('video::public.video.index')
            ->data(compact('videos', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show video.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Video::findBySlug($slug);
        $data = new VideoResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('video::video.name'))
            ->view('video::public.video.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
