<?php

namespace Realestate\Video\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Realestate\Video\Models\Video;

class VideoPolicy
{


    /**
     * Determine if the given user can view the video.
     *
     * @param Authenticatable $user
     * @param Video $video
     *
     * @return bool
     */
    public function view(Authenticatable $user, Video $video)
    {
        if ($authUser->canDo('video.video.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $video->is_owner;
    }

    /**
     * Determine if the given user can create a video.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('video.video.create');
    }

    /**
     * Determine if the given user can update the given video.
     *
     * @param Authenticatable $user
     * @param Video $video
     *
     * @return bool
     */
    public function update(Authenticatable $user, Video $video)
    {
        if ($user->canDo('video.video.edit') && $user->isAdmin()) {
            return true;
        }

        return $video->is_owner;
    }

    /**
     * Determine if the given user can delete the given video.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Video $video)
    {
        return $video->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
